<?php

declare(strict_types=1);
session_start();

use DI\Container;
use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Slim\Factory\AppFactory;
use Users\Model\DB;
use Users\View\Twig;

require __DIR__. '/../vendor/autoload.php';

$container = new Container();

// de container is een lijst van key values pairs, waarbij de value een object is
//of de functie die het object voor de eeerste keer aanmaakt


AppFactory::setContainer($container);
$app = AppFactory::create();  //:: static create

$twig = new Twig('../templates');

$container->set('twig', function() {
  $settings = [];
  return new Twig('../templates'); // constructor methode
});

$container->set('db', function(){
  $settings = [];
  return new DB();
});

// routes definieren


// error handling via middleware altijd plaatsen voor de routes

$app->map(['GET', 'POST'],'/create', function(Request $request, Response $response, $args){
  $db = new DB();
  $db->loadUsers();

  if($request->getMethod()=='GET'){
    $twig = $this->get('twig');
    $vars = ["key"=>"Twig var test", "key2"=>["test","test2","test3"],
            "key3"=>["assoc" =>"assoc array"]];
    $render = $twig->render('create.html.twig',$vars);
    $response->getBody()->write($render); 
    return $response;
  }
  else{
    $parsedBody = $request->getParsedBody();
    $user = new DB();
    $res = $user->createUser($parsedBody);

    if($res){
    return $response->withHeader('Location', '/')->withStatus(302);
    }
    else{
      $err = $user->lastErrorMsg();
      $response->getBody()->write($err);
      return $response->withHeader('Location', '/')->withStatus(302);
    }
  }
  return $response;


});


$app->get('/', \Users\Controller\Index::class.':index');



$app->run();


function addNavbar($twig){
  $urls = [
          ["link"=> "https://www.google.be", "name"=> "Google"],
          ["link"=> "https://www.facebook.com", "name"=> "Google"],
          ["link"=> "https://www.twitter.com", "name"=> "Google"]];
  $twig->addBlockVariable('navbar', ['urls'=> $urls]);
}